@@ -63,10 +63,10 @@
 **  Strings for usage and quick reference
 ******************************************************************************/
 
-char *version = "2.0.0";
+char *version = "2.0.1";
 char *usage = "Usage : fly [-h] [-q] [-i inputfile] [-o outputfile]";
 
-char *help = "See <URL:http://martin.gleeson.com/fly/> for documentation.\n\
+char *help = "See <http://martin.gleeson.net/fly/> for documentation.\n\
 \n\
 Quick Reference to Directives: \n\
 \n\
